package org.bytedream.quizzledizzle.multiplayer;

import org.bytedream.quizzledizzle.question.Question;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.net.Socket;
import java.util.Arrays;
import java.util.Random;

public class Client {
    private final Socket socket;
    private final BufferedReader reader;
    private final PrintWriter writer;
    private final long seed;
    private final Random random;
    private final boolean isServer;

    public Client(Socket socket, BufferedReader reader, PrintWriter writer, long seed, boolean isServer) {
        this.socket = socket;
        this.reader = reader;
        this.writer = writer;
        this.seed = seed;
        this.random = new Random(seed);
        this.isServer = isServer;
    }

    public void sendQuestion(Question question) {
        writer.printf("%s;%s;%s\n", question.getQuestion(), question.getRightAnswerIndex(), String.join(";", question.getAnswers()));
        writer.flush();
    }

    public Question receiveQuestion() throws IOException {
        String[] rawQuestion = reader.readLine().split(";");
        return new Question(rawQuestion[0], Integer.parseInt(rawQuestion[1]), Arrays.copyOfRange(rawQuestion, 2, rawQuestion.length));
    }

    public void sendAnswer(int answerIndex) {
        writer.print(answerIndex);
        writer.flush();
    }

    public int receiveAnswer() throws IOException {
        return Integer.parseInt(reader.readLine());
    }

    public void updateSeed(int count) {
        this.random.setSeed(seed + count);
    }

    /**
     * Returns if the client has to send the next question to the other player
     *
     * @return
     */
    public boolean requestSend() {
        int result = random.nextInt(2);
        if (isServer) {
            return result == 1;
        } else {
            return result == 0;
        }
    }

    public void close() throws IOException {
        socket.close();
    }
}
