package org.bytedream.quizzledizzle.question;

import java.io.*;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Random;

public class Questions {

    private final String[][] questions;

    public Questions(String[][] questions) {
        this.questions = questions;
    }

    /**
     * shows a random question
     *
     * @return
     */
    public Question randomQuestion() {
        String[] chosenQuestion = questions[new Random().nextInt(questions.length)];
        return new Question(chosenQuestion[0], Integer.parseInt(chosenQuestion[1]), Arrays.copyOfRange(chosenQuestion, 2, chosenQuestion.length));
    }

    /**
     * loads questions from a .csv file
     *
     * @param file the file to read from
     * @param delimiter the used delimiter
     * @return
     * @throws IOException if the file does not exist
     */
    public static Questions loadFromCSV(File file, String delimiter) throws IOException {
        BufferedReader reader = new BufferedReader(new FileReader(file));
        ArrayList<String[]> items = new ArrayList<>();

        String line;
        while ((line = reader.readLine()) != null) {
            // if a comment is in the file
            if (line.startsWith("#")) {
                continue;
            }
            items.add(line.split(delimiter));
        }

        return new Questions(items.toArray(String[][]::new));
    }
}
